cosinnus.formats.de package
===========================

Submodules
----------

cosinnus.formats.de.formats module
----------------------------------

.. automodule:: cosinnus.formats.de.formats
    :members:
    :undoc-members:
    :show-inheritance:


Module contents
---------------

.. automodule:: cosinnus.formats.de
    :members:
    :undoc-members:
    :show-inheritance:
